@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -194,7 +194,11 @@ sub new {
       $self->config_data( 'msys' => 0 );
     }
   
-    while(my($tool, $version) = each %{ $self->alien_bin_requires }) {
+    foreach my $tool (keys %{ $self->alien_bin_requires  }) {
+      my $version = $self->alien_bin_requires->{$tool};
+      if($tool eq 'Alien::CMake' && $version < 0.07) {
+        $version = '0.07';
+      }
       $self->_add_prereq( 'build_requires', $tool, $version );
     }
   }
@@ -208,6 +212,10 @@ sub new {
 
   $self->config_data( 'finished_installing' => 0 );
 
+  if(grep /(?<!\%)\%p/, map { ref($_) ? @{$_} : $_ } @{ $self->alien_build_commands }) {
+    carp "%p is deprecated, See https://metacpan.org/pod/distribution/Alien-Base/lib/Alien/Base/ModuleBuild/API.pod#p";
+  }
+
   return $self;
 }
 
@@ -703,7 +711,6 @@ sub alien_do_system {
   my $command = shift;
   
   local %ENV = %ENV;
-  $ENV{PATH} = $ENV{PATH};
   
   if ($self->config_data( 'msys' )) {
     $self->alien_bin_requires->{'Alien::MSYS'} ||= 0
@@ -718,8 +725,6 @@ sub alien_do_system {
     
     if ($mod eq 'Alien::MSYS') {
       $path{Alien::MSYS->msys_path} = 1;
-    } elsif ($mod eq 'Alien::CMake') {
-      Alien::CMake->set_path;
     } elsif ($mod eq 'Alien::TinyCC') {
       $path{Alien::TinyCC->path_to_tcc} = 1;
     } elsif ($mod eq 'Alien::Autotools') {
@@ -1191,7 +1196,7 @@ In your Build.PL:
    module_name => 'Alien::MyLibrary',
    
    configure_requires => {
-     'Alien::Base' =>   '0.005',
+     'Alien::Base::ModuleBuild' => '0.005',
      'Module::Build' => '0.28'
    },
    requires => {
@@ -1259,7 +1264,7 @@ This function determines the version of the library after it has been
 built from source.  This function only gets called if the operating
 system version can not be found and the package is successfully built.
 
-The default implementation relies on C<pkg-config>, and other huristics,
+The default implementation relies on C<pkg-config>, and other heuristics,
 but you will probably want to override this with your own implementation
 if the package you are building does not use C<pkg-config>.
 
