@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild::Repository;
 use strict;
 use warnings;
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -20,6 +20,10 @@ sub new {
   $obj->{c_compiler_required} = 1
     unless defined $obj->{c_compiler_required};
 
+  if($obj->{exact_filename} && $obj->{location} !~ m{/$}) {
+    $obj->{location} .= '/'
+  }
+
   return $obj;
 }
 
