@@ -3,7 +3,7 @@ package Alien::Base::PkgConfig;
 use strict;
 use warnings;
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -144,5 +144,13 @@ sub pkg_config_command {
   $pkg_config_command;
 }
 
+sub TO_JSON
+{
+  my($self) = @_;
+  my %hash = %$self;
+  $hash{'__CLASS__'} = ref($self);
+  \%hash;
+}
+
 1;
 
